# Table of Contents

- [github-app-permissions](<./github-app-permissions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [GitHub App Permissions](<./GitHub-App-Permissions.md>)
  - [Repository Permissions](<./GitHub-App-Permissions/Repository-Permissions.md>)
  - [Organization Permissions](<./GitHub-App-Permissions/Organization-Permissions.md>)
  - [Webhook Events](<./GitHub-App-Permissions/Webhook-Events.md>)
